AudioMetadata class

Audio file metadata

Annotations
  • @immutable

Constructors

AudioMetadata({required String id, String? filename, String? extension, int? size, double? audioDuration, int? numberOfChannels})
Creates a new instance of AudioMetadata
const
AudioMetadata.fromJson(Map<String, dynamic> json)
Creates AudioMetadata from JSON data
factory

Properties

audioDuration double?
Audio duration in seconds
final
extension String?
File extension
final
filename String?
File name
final
hashCode int
The hash code for this object.
no setterinherited
id String
File identifier
final
numberOfChannels int?
Number of audio channels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
File size in bytes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited