BaseResponse class

Base class for Gladia API response

Implementers
Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

BaseResponse({required String id, required String status, String? requestId, int? version, DateTime? createdAt, DateTime? completedAt, Map<String, dynamic>? customMetadata, int? errorCode, String? kind})
Creates a new instance of BaseResponse
const
BaseResponse.fromJson(Map<String, dynamic> json)
Creates BaseResponse from JSON data
factory

Properties

completedAt DateTime?
Request completion time
final
createdAt DateTime?
Request creation time
final
customMetadata Map<String, dynamic>?
Custom metadata
final
errorCode int?
Error code, if any
final
hashCode int
The hash code for this object.
no setterinherited
id String
Transcription identifier
final
kind String?
Request type
final
requestId String?
Request identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Request status
final
version int?
API version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dateTimeFromJson(dynamic value) DateTime?
Converts string to DateTime
dateTimeToJson(DateTime? date) String?
Converts DateTime to ISO 8601 string