Encoding enum

Enumeration of available audio encoding formats

Inheritance
Available extensions

Values

pcm → const Encoding

PCM format (default)

ulaw → const Encoding

μ-law format (8 bit)

alaw → const Encoding

A-law format (8 bit)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toApiValue() String

Available on Encoding, provided by the EncodingExtension extension

Converts enum to string value for API
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Encoding>
A constant List of the values in this enum, in order of their declaration.