FileInfo class

File information from Gladia API

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

FileInfo({String? id, String? filename, String? source, double? audioDuration, int? numberOfChannels})
Creates a new instance of FileInfo
const
FileInfo.fromJson(Map<String, dynamic> json)
Creates FileInfo from JSON data
factory

Properties

audioDuration double?
Audio duration in seconds
final
filename String?
Filename
final
hashCode int
The hash code for this object.
no setterinherited
id String?
File identifier
final
numberOfChannels int?
Number of audio channels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
File source
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited