GladiaApiException class

Exception when working with Gladia API

Implemented types

Constructors

GladiaApiException({required String message, int? statusCode, Map<String, dynamic>? responseData, List<Map<String, dynamic>>? validationErrors, Object? innerException, String? innerExceptionMessage, StackTrace? stackTrace, bool includeDebugInfo = false})
Creates a new instance of GladiaApiException
GladiaApiException.fromDioError(DioException error, {StackTrace? stackTrace, bool includeDebugInfo = false})
Creates exception from Dio error
factory

Properties

debugInfo String?
Returns detailed debug information
no setter
formattedValidationErrors String?
Returns string representation of all validation errors
no setter
hashCode int
The hash code for this object.
no setterinherited
includeDebugInfo bool
Whether the exception includes debug information
final
innerException Object?
Original exception, if available
final
innerExceptionMessage String?
Additional message about inner exception
final
message String
Error message
final
responseData Map<String, dynamic>?
Response data, if available
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Exception stack trace
final
statusCode int?
HTTP status code, if applicable
final
validationErrors List<Map<String, dynamic>>?
Validation errors, if available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited