GladiaServiceType enum
Gladia API service types
Values
- audio → const GladiaServiceType
-
Audio service (transcription)
const GladiaServiceType('audio') - text → const GladiaServiceType
-
Text service (NLP)
const GladiaServiceType('text') - video → const GladiaServiceType
-
Video service
const GladiaServiceType('video')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
String representation for API
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GladiaServiceType> - A constant List of the values in this enum, in order of their declaration.