LiveSessionInitResult class

Model of real-time speech recognition session initialization result

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

LiveSessionInitResult({required String id, required String url})
Creates a new instance of LiveSessionInitResult
const
LiveSessionInitResult.fromJson(Map<String, dynamic> json)
Creates LiveSessionInitResult from JSON data
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Session identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
URL for WebSocket connection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited