LiveTranscriptionOptions class

Options for the transcription process

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

LiveTranscriptionOptions({Encoding? encoding, BitDepth? bitDepth, SampleRate? sampleRate, int? channels, Map<String, dynamic>? customMetadata, String? model, double? endpointing, double? maximumDurationWithoutEndpointing, LanguageConfig? languageConfig, PreProcessing? preProcessing, RealtimeProcessing? realtimeProcessing, PostProcessing? postProcessing, MessagesConfig? messagesConfig, bool? callback, CallbackConfig? callbackConfig})
Creates a new instance of LiveTranscriptionOptions
const
LiveTranscriptionOptions.fromJson(Map<String, dynamic> json)
factory

Properties

bitDepth BitDepth?
The bit depth of the audio stream
final
callback bool?
If true, messages will be sent to configured url. Default: false
final
callbackConfig → CallbackConfig?
Specify the callback configuration
final
channels int?
The number of channels of the audio stream Required range: 1 <= x <= 8
final
customMetadata Map<String, dynamic>?
Custom metadata you can attach to this live transcription Example: { "user": "John Doe" }
final
encoding Encoding?
The encoding format of the audio stream
final
endpointing double?
The endpointing duration in seconds. Endpointing is the duration of silence which will cause an utterance to be considered as finished Required range: 0.01 <= x <= 10 Default: 0.05
final
hashCode int
The hash code for this object.
no setterinherited
languageConfig LanguageConfig?
Конфигурация языка
final
maximumDurationWithoutEndpointing double?
The maximum duration in seconds without endpointing. If endpointing is not detected after this duration, current utterance will be considered as finished Required range: 5 <= x <= 60 Default: 5
final
messagesConfig → MessagesConfig?
Specify the websocket messages configuration
final
model String?
The model used to process the audio. "solaria-1" is used by default. Available options:
final
postProcessing → PostProcessing?
Specify the post-processing configuration
final
preProcessing → PreProcessing?
Конфигурация предварительной обработки
final
realtimeProcessing → RealtimeProcessing?
Конфигурация обработки в реальном времени
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate SampleRate?
The sample rate of the audio stream
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited