endpointing property

  1. @JsonKey.new(name: 'endpointing')
double? endpointing
final

The endpointing duration in seconds. Endpointing is the duration of silence which will cause an utterance to be considered as finished Required range: 0.01 <= x <= 10 Default: 0.05

Implementation

@JsonKey(name: 'endpointing')
final double? endpointing;