LiveTranscriptionResult class
Complete audio transcription result from Gladia API
- Inheritance
-
- Object
- BaseResponse
- LiveTranscriptionResult
- Annotations
-
- @immutable
- @JsonSerializable.new()
Constructors
-
LiveTranscriptionResult({required String id, required String status, String? requestId, int? version, DateTime? createdAt, DateTime? completedAt, Map<
String, dynamic> ? customMetadata, int? errorCode, String? kind, FileInfo? file, LiveTranscriptionOptions? requestParams, LiveTranscriptionResultData? result}) -
Creates a new instance of LiveTranscriptionResult
const
-
LiveTranscriptionResult.fromJson(Map<
String, dynamic> json) -
Creates LiveTranscriptionResult from JSON data
factory
Properties
- completedAt → DateTime?
-
Request completion time
finalinherited
- createdAt → DateTime?
-
Request creation time
finalinherited
-
customMetadata
→ Map<
String, dynamic> ? -
Custom metadata
finalinherited
- errorCode → int?
-
Error code, if any
finalinherited
- file → FileInfo?
-
Audio file information
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Transcription identifier
finalinherited
- kind → String?
-
Request type
finalinherited
- language → String?
-
Returns the language for compatibility with the old version
no setter
- requestId → String?
-
Request identifier
finalinherited
- requestParams → LiveTranscriptionOptions?
-
Request parameters
final
- result → LiveTranscriptionResultData?
-
Transcription results and additional functions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
Request status
finalinherited
- text → String
-
Returns the full transcription text for compatibility with the old version
no setter
-
utterances
→ List<
Utterance> ? -
Returns segments for compatibility with the old version
no setter
- version → int?
-
API version
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited