text property
String
get
text
Returns the full transcription text for compatibility with the old version
Implementation
String get text => result?.transcription?.fullTranscript ?? '';
Returns the full transcription text for compatibility with the old version
String get text => result?.transcription?.fullTranscript ?? '';