SubtitleData class

Subtitle data

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

SubtitleData({required String format, required String subtitles})
Creates a new instance of SubtitleData
const
SubtitleData.fromJson(Map<String, dynamic> json)
Creates SubtitleData from JSON data
factory

Properties

format String
Subtitle format
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitles String
Subtitle text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited