TranscriptionData class

Basic transcription data

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

TranscriptionData({bool? success, bool? isEmpty, double? execTime, ErrorData? error, required String fullTranscript, List<String>? languages, List<SentenceData>? sentences, List<SubtitleData>? subtitles, List<TranscriptionSegment>? utterances})
Creates a new instance of TranscriptionData
const
TranscriptionData.fromJson(Map<String, dynamic> json)
Creates TranscriptionData from JSON data
factory

Properties

error → ErrorData?
Error information if unsuccessful
finalinherited
execTime double?
Execution time
finalinherited
fullTranscript String
Full transcription text
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool?
Empty result indicator
finalinherited
languages List<String>?
Languages detected in audio
final
results String?
Results data
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentences List<SentenceData>?
Transcription sentences
final
subtitles List<SubtitleData>?
Transcription subtitles
final
success bool?
Success status
finalinherited
utterances List<TranscriptionSegment>?
Utterances with time stamps
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited