TranscriptionInitResult class

Transcription initialization result from Gladia API

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

TranscriptionInitResult({required String id, required String resultUrl, String? requestId})
Creates a new instance of TranscriptionInitResult
const
TranscriptionInitResult.fromJson(Map<String, dynamic> json)
Creates TranscriptionInitResult from JSON data
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Transcription identifier
final
requestId String?
Request identifier (in new API)
final
resultUrl String
URL for obtaining transcription result
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited