TranscriptionMessage class

Class for messages received from API during real-time speech recognition

Constructors

TranscriptionMessage({required String type, required String sessionId, required DateTime createdAt, required TranscriptionMessageData data})
Creates a new instance of TranscriptionMessage
const
TranscriptionMessage.fromJson(Map<String, dynamic> json)
Creates TranscriptionMessage from JSON data
factory

Properties

createdAt DateTime
Message creation time
final
data TranscriptionMessageData
Message data
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
Session ID
final
type String
Message type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts object to JSON data
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited