TranscriptionMetadata class

Transcription result metadata

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

TranscriptionMetadata({double? audioDuration, int? numberOfDistinctChannels, double? billingTime, double? transcriptionTime})
Creates a new instance of TranscriptionMetadata
const
TranscriptionMetadata.fromJson(Map<String, dynamic> json)
Creates TranscriptionMetadata from JSON data
factory

Properties

audioDuration double?
Audio duration in seconds
final
billingTime double?
Billing time
final
hashCode int
The hash code for this object.
no setterinherited
numberOfDistinctChannels int?
Number of distinct audio channels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transcriptionTime double?
Transcription processing time in seconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited