TranscriptionOptions class

Options for transcription process

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

TranscriptionOptions({String? contextPrompt, bool? customVocabulary, CustomVocabularyConfig? customVocabularyConfig, String? language, bool? callback, CallbackConfig? callbackConfig, bool? subtitles, SubtitlesConfig? subtitlesConfig, bool? diarization, DiarizationConfig? diarizationConfig, bool? translation, TranslationConfig? translationConfig, bool? summarization, SummarizationConfig? summarizationConfig, bool? moderation, bool? namedEntityRecognition, bool? chapterization, bool? namesConsistency, bool? customSpelling, CustomSpellingConfig? customSpellingConfig, bool? structuredDataExtraction, StructuredDataExtractionConfig? structuredDataExtractionConfig, bool? sentimentAnalysis, bool? audioToLLM, AudioToLLMConfig? audioToLLMConfig, Map<String, dynamic>? customMetadata, bool? sentences, String? displayMode, bool? enhancedPunctuation, LanguageConfig? languageConfig})
Creates a new instance of TranscriptionOptions
const
TranscriptionOptions.fromJson(Map<String, dynamic> json)
factory

Properties

audioToLLM bool?
Alpha Enable audio to llm processing for this audio
final
audioToLLMConfig → AudioToLLMConfig?
Alpha Audio to llm configuration, if audio_to_llm is enabled
final
callback bool?
Enable callback for this transcription. If true, the callback_config property will be used to customize the callback behaviour
final
callbackConfig → CallbackConfig?
Customize the callback behaviour (url and http method)
final
chapterization bool?
Alpha Enable chapterization for this audio
final
contextPrompt String?
Alpha Context to feed the transcription model with for possible better accuracy
final
customMetadata Map<String, dynamic>?
Custom metadata you can attach to this transcription
final
customSpelling bool?
Alpha Enable custom spelling for this audio
final
customSpellingConfig → CustomSpellingConfig?
Alpha Custom spelling configuration, if custom_spelling is enabled
final
customVocabulary bool?
Beta Can be either boolean to enable custom_vocabulary for this audio or an array with specific vocabulary list to feed the transcription model with
final
customVocabularyConfig → CustomVocabularyConfig?
Beta Custom vocabulary configuration, if custom_vocabulary is enabled
final
diarization bool?
Enable speaker recognition (diarization) for this audio
final
diarizationConfig → DiarizationConfig?
Speaker recognition configuration, if diarization is enabled
final
displayMode String?
Alpha Allows to change the output display_mode for this audio. The output will be reordered, creating new utterances when speakers overlapped Default: false
final
enhancedPunctuation bool?
Alpha Use enhanced punctuation for this audio Default: false
final
hashCode int
The hash code for this object.
no setterinherited
language String?
The original language in iso639-1 format
final
languageConfig LanguageConfig?
Specify the language configuration
final
moderation bool?
Alpha Enable moderation for this audio
final
namedEntityRecognition bool?
Alpha Enable named entity recognition for this audio
final
namesConsistency bool?
Alpha Enable names consistency for this audio
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentences bool?
Enable sentences for this audio Default: false
final
sentimentAnalysis bool?
Alpha Enable sentiment analysis for this audio
final
structuredDataExtraction bool?
Alpha Enable structured data extraction for this audio
final
structuredDataExtractionConfig → StructuredDataExtractionConfig?
Alpha Structured data extraction configuration, if structured_data_extraction is enabled
final
subtitles bool?
Enable subtitles generation for this transcription
final
subtitlesConfig → SubtitlesConfig?
Configuration for subtitles generation if subtitles is enabled
final
summarization bool?
Beta Enable summarization for this audio
final
summarizationConfig → SummarizationConfig?
Beta Summarization configuration, if summarization is enabled
final
translation bool?
Beta Enable translation for this audio
final
translationConfig → TranslationConfig?
Beta Translation configuration, if translation is enabled
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited