callback property
Enable callback for this transcription. If true, the callback_config property will be used to customize the callback behaviour
Implementation
@JsonKey(name: 'callback')
final bool? callback;
Enable callback for this transcription. If true, the callback_config property will be used to customize the callback behaviour
@JsonKey(name: 'callback')
final bool? callback;