contextPrompt property
Alpha Context to feed the transcription model with for possible better accuracy
Implementation
@JsonKey(name: 'context_prompt')
final String? contextPrompt;
Alpha Context to feed the transcription model with for possible better accuracy
@JsonKey(name: 'context_prompt')
final String? contextPrompt;