TranscriptionSegment class

Transcription segment with time stamps and additional information

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

TranscriptionSegment({required String text, required double start, required double end, int? speaker, double? confidence, String? language, int? channel, List<Word>? words})
Creates a new instance of TranscriptionSegment
const
TranscriptionSegment.fromJson(Map<String, dynamic> json)
Creates TranscriptionSegment from JSON data
factory

Properties

channel int?
Audio channel
final
confidence double?
Confidence in identification (0 to 1)
final
end double
Segment end time in seconds
final
hashCode int
The hash code for this object.
no setterinherited
language String?
Segment language (if available)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speaker int?
Speaker identifier (if speaker diarization is available)
final
start double
Segment start time in seconds
final
text String
Segment text
final
words List<Word>?
Words in segment with time stamps
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited