UtteranceInfo class
Utterance information
Constructors
- UtteranceInfo({required String text, required double start, required double end, required String language, int? channel})
-
Creates a new instance of UtteranceInfo
const
-
UtteranceInfo.fromJson(Map<
String, dynamic> json) -
Creates UtteranceInfo from JSON data
factory
Properties
- channel → int?
-
Channel number (for multi-channel audio)
final
- end → double
-
Utterance end time (in seconds)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String
-
Utterance language (ISO code)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → double
-
Utterance start time (in seconds)
final
- text → String
-
Utterance text
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts object to JSON data
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited