Word class

Word with time stamp

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

Word({required String text, required double start, required double end, double? confidence})
Creates a new instance of Word
const
Word.fromJson(Map<String, dynamic> json)
Creates Word from JSON data
factory

Properties

confidence double?
Confidence in identification (0 to 1)
final
end double
Word end time in seconds
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double
Word start time in seconds
final
text String
Word text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited