LanguageConfig class
Language configuration for transcription
- Annotations
-
- @immutable
- @JsonSerializable.new()
Constructors
-
LanguageConfig({List<
String> ? languages, bool? codeSwitching}) -
Creates a new instance of LanguageConfig
const
-
LanguageConfig.fromJson(Map<
String, dynamic> json) -
Creates LanguageConfig from JSON data
factory
Properties
- codeSwitching → bool?
-
If true, the language will be determined for each utterance
Otherwise, the language will be determined for the first utterance and used for the rest
Ignored if a single language is set
Default: false
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
→ List<
String> ? -
Languages for determination
If a single language is set, it will be used for transcription
Otherwise, the language will be determined automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited