SampleRate enum
Enumeration of available audio sampling rate values
Values
- hz8000 → const SampleRate
-
8000 Hz
const SampleRate(8000) - hz16000 → const SampleRate
-
16000 Hz (default)
const SampleRate(16000) - hz32000 → const SampleRate
-
32000 Hz
const SampleRate(32000) - hz44100 → const SampleRate
-
44100 Hz
const SampleRate(44100) - hz48000 → const SampleRate
-
48000 Hz
const SampleRate(48000)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Sampling rate value in Hz
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int? value) → SampleRate? - Creates SampleRate from integer value
Constants
-
values
→ const List<
SampleRate> - A constant List of the values in this enum, in order of their declaration.