SentenceData class
Sentence data
- Annotations
-
- @immutable
- @JsonSerializable.new()
Constructors
-
SentenceData({bool? success, bool? isEmpty, double? execTime, ErrorData? error, List<
String> ? results}) -
Creates a new instance of SentenceData
const
-
SentenceData.fromJson(Map<
String, dynamic> json) -
Creates SentenceData from JSON data
factory
Properties
- error → ErrorData?
-
Error information if unsuccessful
finalinherited
- execTime → double?
-
Execution time
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool?
-
Empty result indicator
finalinherited
- results → String?
-
Returns results
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool?
-
Success status
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited