TranscriptionMessageData class
Transcription message data
Constructors
- TranscriptionMessageData({required String id, required bool isFinal, required UtteranceInfo utterance})
-
Creates a new instance of TranscriptionMessageData
const
-
TranscriptionMessageData.fromJson(Map<
String, dynamic> json) -
Creates TranscriptionMessageData from JSON data
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Utterance ID
final
- isFinal → bool
-
Final utterance indicator
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- utterance → UtteranceInfo
-
Utterance information
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts object to JSON data
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited