TranscriptionOptions class
Options for transcription process
- Annotations
-
- @immutable
- @JsonSerializable.new()
Constructors
-
TranscriptionOptions({String? contextPrompt, bool? customVocabulary, CustomVocabularyConfig? customVocabularyConfig, String? language, bool? callback, CallbackConfig? callbackConfig, bool? subtitles, SubtitlesConfig? subtitlesConfig, bool? diarization, DiarizationConfig? diarizationConfig, bool? translation, TranslationConfig? translationConfig, bool? summarization, SummarizationConfig? summarizationConfig, bool? moderation, bool? namedEntityRecognition, bool? chapterization, bool? namesConsistency, bool? customSpelling, CustomSpellingConfig? customSpellingConfig, bool? structuredDataExtraction, StructuredDataExtractionConfig? structuredDataExtractionConfig, bool? sentimentAnalysis, bool? audioToLLM, AudioToLLMConfig? audioToLLMConfig, Map<
String, dynamic> ? customMetadata, bool? sentences, String? displayMode, bool? enhancedPunctuation, LanguageConfig? languageConfig}) -
Creates a new instance of TranscriptionOptions
const
-
TranscriptionOptions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- audioToLLM → bool?
-
AlphaEnable audio to llm processing for this audiofinal - audioToLLMConfig → AudioToLLMConfig?
-
AlphaAudio to llm configuration, if audio_to_llm is enabledfinal - callback → bool?
-
Enable callback for this transcription. If true, the callback_config property will be used to customize the callback behaviour
final
- callbackConfig → CallbackConfig?
-
Customize the callback behaviour (url and http method)
final
- chapterization → bool?
-
AlphaEnable chapterization for this audiofinal - contextPrompt → String?
-
AlphaContext to feed the transcription model with for possible better accuracyfinal -
customMetadata
→ Map<
String, dynamic> ? -
Custom metadata you can attach to this transcription
final
- customSpelling → bool?
-
AlphaEnable custom spelling for this audiofinal - customSpellingConfig → CustomSpellingConfig?
-
AlphaCustom spelling configuration, if custom_spelling is enabledfinal - customVocabulary → bool?
-
BetaCan be either boolean to enable custom_vocabulary for this audio or an array with specific vocabulary list to feed the transcription model withfinal - customVocabularyConfig → CustomVocabularyConfig?
-
BetaCustom vocabulary configuration, if custom_vocabulary is enabledfinal - diarization → bool?
-
Enable speaker recognition (diarization) for this audio
final
- diarizationConfig → DiarizationConfig?
-
Speaker recognition configuration, if diarization is enabled
final
- displayMode → String?
-
AlphaAllows to change the output display_mode for this audio. The output will be reordered, creating new utterances when speakers overlapped Default: falsefinal - enhancedPunctuation → bool?
-
AlphaUse enhanced punctuation for this audio Default: falsefinal - hashCode → int
-
The hash code for this object.
no setterinherited
- language → String?
-
The original language in iso639-1 format
final
- languageConfig → LanguageConfig?
-
Specify the language configuration
final
- moderation → bool?
-
AlphaEnable moderation for this audiofinal - namedEntityRecognition → bool?
-
AlphaEnable named entity recognition for this audiofinal - namesConsistency → bool?
-
AlphaEnable names consistency for this audiofinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentences → bool?
-
Enable sentences for this audio
Default: false
final
- sentimentAnalysis → bool?
-
AlphaEnable sentiment analysis for this audiofinal - structuredDataExtraction → bool?
-
AlphaEnable structured data extraction for this audiofinal - structuredDataExtractionConfig → StructuredDataExtractionConfig?
-
AlphaStructured data extraction configuration, if structured_data_extraction is enabledfinal - subtitles → bool?
-
Enable subtitles generation for this transcription
final
- subtitlesConfig → SubtitlesConfig?
-
Configuration for subtitles generation if subtitles is enabled
final
- summarization → bool?
-
BetaEnable summarization for this audiofinal - summarizationConfig → SummarizationConfig?
-
BetaSummarization configuration, if summarization is enabledfinal - translation → bool?
-
BetaEnable translation for this audiofinal - translationConfig → TranslationConfig?
-
BetaTranslation configuration, if translation is enabledfinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited