customVocabulary property
Beta Can be either boolean to enable custom_vocabulary for this audio or an array with specific vocabulary list to feed the transcription model with
Implementation
@JsonKey(name: 'custom_vocabulary')
final bool? customVocabulary;