UploadResult class
Result of uploading audio file to Gladia API
- Annotations
-
- @immutable
Constructors
- UploadResult({required String audioUrl, AudioMetadata? audioMetadata})
-
Creates a new instance of UploadResult
const
-
UploadResult.fromJson(Map<
String, dynamic> json) -
Creates UploadResult from JSON data
factory
Properties
- audioMetadata → AudioMetadata?
-
Audio file metadata
final
- audioUrl → String
-
URL of the uploaded audio file
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited